==> haskell-text-zipper-0.10.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-text-zipper.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-zipper
version: 0.10.1
id: text-zipper-0.10.1-5anw58L5L9nGBx6ICflo2w
key: text-zipper-0.10.1-5anw58L5L9nGBx6ICflo2w
license: BSD3
copyright: (c) 2015 Jonathan Daugherty
maintainer: cygnus@foobox.com
homepage: https://github.com/jtdaugherty/text-zipper/
synopsis: A text editor zipper library
description:
    This library provides a zipper and API for editing text.
category: Text
author: Jonathan Daugherty <cygnus@foobox.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Text.Zipper Data.Text.Zipper.Generic
    Data.Text.Zipper.Generic.Words
hidden-modules: Data.Text.Zipper.Vector
abi: 72925df98680edb1f9c2bc74ba58621d
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/text-zipper-0.10.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/text-zipper-0.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/text-zipper-0.10.1
hs-libraries: HStext-zipper-0.10.1-5anw58L5L9nGBx6ICflo2w
depends:
    base-4.10.0.0 text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi deepseq-1.4.3.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
haddock-interfaces: /usr/share/doc/haskell-text-zipper/html/text-zipper.haddock
haddock-html: /usr/share/doc/haskell-text-zipper/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-zipper-0.10-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-text-zipper.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-zipper
version: 0.10
id: text-zipper-0.10-JsGhYyq2LwDw2Inrm2TZS
key: text-zipper-0.10-JsGhYyq2LwDw2Inrm2TZS
license: BSD3
copyright: (c) 2015 Jonathan Daugherty
maintainer: cygnus@foobox.com
homepage: https://github.com/jtdaugherty/text-zipper/
synopsis: A text editor zipper library
description:
    This library provides a zipper and API for editing text.
category: Text
author: Jonathan Daugherty <cygnus@foobox.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Text.Zipper Data.Text.Zipper.Generic
    Data.Text.Zipper.Generic.Words
hidden-modules: Data.Text.Zipper.Vector
abi: 8a268e65972c11a5f09074a8a8ec1026
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/text-zipper-0.10
library-dirs: /usr/lib/ghc-8.2.1/site-local/text-zipper-0.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/text-zipper-0.10
hs-libraries: HStext-zipper-0.10-JsGhYyq2LwDw2Inrm2TZS
depends:
    base-4.10.0.0 text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi deepseq-1.4.3.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
haddock-interfaces: /usr/share/doc/haskell-text-zipper/html/text-zipper.haddock
haddock-html: /usr/share/doc/haskell-text-zipper/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
